@@ -35,6 +35,7 @@ namespace inserttimestamp {
   {
     ADD_INTERFACE_IMPL(InsertTimestampNoteAddin);
     ADD_INTERFACE_IMPL(InsertTimestampPreferencesFactory);
+    enabled(false);
   }
   const char * InsertTimeStampModule::id() const
   {
@@ -52,13 +53,13 @@ namespace inserttimestamp {
   {
     return _("Hubert Figuiere and Tomboy Project");
   }
-  const char * InsertTimeStampModule::category() const
+  int InsertTimeStampModule::category() const
   {
-    return "Tools";
+    return gnote::ADDIN_CATEGORY_TOOLS;
   }
   const char * InsertTimeStampModule::version() const
   {
-    return "0.1";
+    return "0.1.1";
   }
 
 
