@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -48,7 +49,6 @@
 #include "recentchanges.hpp"
 #include "utils.hpp"
 #include "xkeybinder.hpp"
-#include "sharp/string.hpp"
 #include "sharp/streamreader.hpp"
 #include "sharp/files.hpp"
 
@@ -111,13 +111,8 @@ namespace gnote {
     am.load_interface();
     register_remote_control(*m_manager);
     setup_global_actions();
-    
-    std::list<ApplicationAddin*> addins;
-    m_manager->get_addin_manager().get_application_addins(addins);
-    for(std::list<ApplicationAddin*>::const_iterator iter = addins.begin();
-        iter != addins.end(); ++iter) {
-      (*iter)->initialize();
-    }
+
+    m_manager->get_addin_manager().initialize_application_addins();
 
 #ifndef ENABLE_DBUS
     if(cmd_line.needs_execute()) {
@@ -169,13 +164,7 @@ namespace gnote {
       note_path = override_path;
     }
     if(note_path.empty()) {
-      note_path = Gnote::conf_dir();
-    }
-    std::string home_dir;
-    const char *s = getenv("HOME");
-    if(s) {
-      home_dir = s;
-      note_path = sharp::string_replace_first(note_path, "~", home_dir);
+      note_path = Gnote::data_dir();
     }
 
     return note_path;
@@ -330,7 +319,10 @@ namespace gnote {
   void Gnote::on_show_about_action()
   {
     std::list<Glib::ustring> authors;
+    authors.push_back("Aurimas Černius <aurisc4@gmail.com>");
+    authors.push_back("Debarshi Ray <debarshir@src.gnome.org>");
     authors.push_back("Hubert Figuiere <hub@figuiere.net>");
+    authors.push_back("Iain Nicol <iainn@src.gnome.org>");
     authors.push_back(_("and Tomboy original authors."));
     
     std::list<Glib::ustring> documenters;
@@ -348,7 +340,8 @@ namespace gnote {
     about.set_name("Gnote");
     about.set_version(VERSION);
     about.set_logo(utils::get_icon("gnote", 48));
-    about.set_copyright(_("Copyright \xc2\xa9 2009 Hubert Figuiere\n"
+    about.set_copyright(_("Copyright \xc2\xa9 2009-2010 Debarshi Ray\n"
+                          "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
                           "Copyright \xc2\xa9 2004-2009 the Tomboy original authors."));
     about.set_comments(_("A simple and easy to use desktop "
                          "note-taking application."));
@@ -388,15 +381,32 @@ namespace gnote {
   }
 
 
+  std::string Gnote::cache_dir()
+  {
+    return Glib::get_user_cache_dir() + "/gnote";
+  }
+
+
   std::string Gnote::conf_dir()
   {
-    std::string dir;
-    const char * home = getenv("HOME");
-    if(!home) {
-      home = ".";
-    }
-    dir = std::string(home) + "/.gnote";
-    return dir;
+    return Glib::get_user_config_dir() + "/gnote";
+  }
+
+
+  std::string Gnote::data_dir()
+  {
+    return Glib::get_user_data_dir() + "/gnote";
+  }
+
+
+  std::string Gnote::old_note_dir()
+  {
+    std::string home_dir = Glib::get_home_dir();
+
+    if (home_dir.empty())
+      home_dir = Glib::get_current_dir();
+
+    return home_dir + "/.gnote";
   }
 
 
@@ -430,6 +440,9 @@ namespace gnote {
     GOptionGroup *group = g_option_group_new("Gnote", _("A note taking application"), _("Gnote options at launch"), this, NULL);
     g_option_group_add_entries(group, entries);
     g_option_context_set_main_group (m_context, group);
+
+    // we need this for the panel support.
+    g_option_context_set_ignore_unknown_options(m_context, TRUE);
   }
 
   
@@ -471,7 +484,7 @@ namespace gnote {
     }
 
     if(m_open_note && *m_open_note) {
-      if (sharp::string_starts_with(m_open_note, "note://gnote/")) {
+      if (Glib::str_has_prefix(m_open_note, "note://gnote/")) {
         m_open_note_uri = m_open_note;
       }
       else if (sharp::file_exists(m_open_note)) {
