@@ -326,7 +326,7 @@ namespace gnote {
     // to have multiple lines in a single bullet point
     if (prev_depth && soft_break) {
       bool at_end_of_line = insert_iter.ends_line();
-      insert_iter = insert(insert_iter, Glib::ustring(4, (gunichar)0x2028));
+      insert_iter = insert(insert_iter, Glib::ustring(1, (gunichar)0x2028));
         
       // Hack so that the user sees that what they type
       // next will appear on a new line, otherwise the
@@ -862,7 +862,7 @@ namespace gnote {
       if (toggle_on && !find_depth_tag(curr_line)) {
         increase_depth(curr_line);
       } 
-      else if (!toggle_on && !find_depth_tag(curr_line)) {
+      else if (!toggle_on && find_depth_tag(curr_line)) {
         Gtk::TextIter bullet_end = get_iter_at_line_offset(curr_line.get_line(), 2);
         erase(curr_line, bullet_end);
       }
@@ -886,9 +886,6 @@ namespace gnote {
     start.set_line_offset(0);
     DepthNoteTag::Ptr start_depth = find_depth_tag (start);
 
-    bool rtl_depth = start_depth && (start_depth->get_direction() == Pango::DIRECTION_RTL);
-    bool first_char_rtl = (start.get_char() > 0) &&
-      (pango_unichar_direction(start.get_char()) == PANGO_DIRECTION_RTL);
     Gtk::TextIter next = start;
 
     if (start_depth) {
@@ -899,15 +896,8 @@ namespace gnote {
       // and use that to determine what direction we should go
       next.forward_sentence_end ();
       next.backward_sentence_start ();
-      first_char_rtl = ((next.get_char() > 0) &&
-                        (pango_unichar_direction(next.get_char() == Pango::DIRECTION_RTL)));
     }
 
-    if ((rtl_depth || first_char_rtl) &&
-        ((next.get_line() == start.get_line()) && !next.ends_line ())) {
-      increase = !right;
-    }
-        
     change_cursor_depth(increase);
   }
 
@@ -1161,6 +1151,14 @@ namespace gnote {
 
     xml.write_start_element ("", "note-content", "");
     xml.write_attribute_string ("", "version", "", "0.1");
+    xml.write_attribute_string("xmlns",
+                               "link",
+                               "",
+                               "http://beatniksoftware.com/tomboy/link");
+    xml.write_attribute_string("xmlns",
+                               "size",
+                               "",
+                               "http://beatniksoftware.com/tomboy/size");
 
     // Insert any active tags at start into tag_stack...
     Glib::SListHandle<Glib::RefPtr<const Gtk::TextTag> > tag_list = start.get_tags();
