@@ -124,7 +124,6 @@ namespace gnote {
       }
       GError *error = NULL;
 
-#ifdef HAVE_GTK_SHOW_URI
       if(!gtk_show_uri (screen, uri.c_str(), gtk_get_current_event_time (), &error)) {
         
         std::string message = _("The \"Gnote Manual\" could "
@@ -142,9 +141,6 @@ namespace gnote {
           g_error_free(error);
         }
       }
-#else
-      Glib::spawn_command_line_async ("xdg-open " + uri);
-#endif
     }
 
 
@@ -154,11 +150,7 @@ namespace gnote {
       if(!url.empty()) {
         GError *err = NULL;
         DBG_OUT("Opening url '%s'...", url.c_str());
-#ifdef HAVE_GTK_SHOW_URI
         gtk_show_uri (NULL, url.c_str(), GDK_CURRENT_TIME, &err);
-#else
-        Glib::spawn_command_line_async ("xdg-open " + url);
-#endif
         if(err) {
           throw Glib::Error(err, true);
         }
@@ -189,12 +181,14 @@ namespace gnote {
       if (date.year() == now.year()) {
         if (date.day_of_year() == now.day_of_year()) {
           pretty_str = show_time ?
+            /* TRANSLATORS: argument is time. */
             str(boost::format(_("Today, %1%")) % short_time) :
             _("Today");
         }
         else if ((date.day_of_year() < now.day_of_year())
                  && (date.day_of_year() == now.day_of_year() - 1)) {
           pretty_str = show_time ?
+            /* TRANSLATORS: argument is time. */
             str(boost::format(_("Yesterday, %1%")) % short_time) :
             _("Yesterday");
         }
@@ -203,10 +197,14 @@ namespace gnote {
           int num_days = now.day_of_year() - date.day_of_year();
           const char * fmt;
           if(show_time) {
+            /* TRANSLATORS: 2 or more days ago, up to one week.
+               First argument is number of days, second is time. */
             fmt = ngettext("%1% day ago, %2%", "%1% days ago, %2%", num_days);
             pretty_str = str(boost::format(fmt) % num_days % short_time);
           }
           else {
+            /* TRANSLATORS: 2 or more days ago, up to one week.
+               Argument is number of days. */
             fmt = ngettext("%1% day ago", "%1% days ago", num_days);
             pretty_str = str(boost::format(fmt) % num_days);
           }
@@ -214,6 +212,7 @@ namespace gnote {
         else if (date.day_of_year() > now.day_of_year()
                  && date.day_of_year() == now.day_of_year() + 1) {
           pretty_str = show_time ?
+            /* TRANSLATORS: argument is time. */
             str(boost::format(_("Tomorrow, %1%")) % short_time) :
             _("Tomorrow");
         }
@@ -222,10 +221,14 @@ namespace gnote {
           int num_days = date.day_of_year() - now.day_of_year();
           const char * fmt;
           if(show_time) {
+            /* TRANSLATORS: In 2 or more days, up to one week.
+               First argument is number of days, second is time. */
             fmt = ngettext("In %1% day, %2%", "In %1% days, %2%", num_days);
             pretty_str = str(boost::format(fmt) % num_days % short_time); 
           }
           else {
+            /* TRANSLATORS: In 2 or more days, up to one week.
+               Argument is number of days. */
             fmt = ngettext("In %1% day", "In %1% days", num_days);
             pretty_str = str(boost::format(fmt) % num_days);
           }
